find_desir_threshold_for_FDR: find_desir_threshold_for_FDR

Description Usage Arguments Value Author(s)

View source: R/find_desir_threshold_for_FDR.R

Description

Finds the Desirability threshold that corresponds to a given FDR % for shared hits.

Usage

1
2
3
4
5
6
7
find_desir_threshold_for_FDR(
  data,
  start_desir,
  stop_desir = NULL,
  fdr_thresh = 0.1,
  step_size = 0.1
)

Arguments

data

A data frame of Desirability scores produced by crispRutils::join_desirability_scores.

start_desir

A numeric value giving the desirability value to start at.

stop_desir

A numeric value giving the desirability value to finish at. If NULL then fdr_thresh is used for stopping. Defaults to NULL.

fdr_thresh

A numeric value giving the FDR threshold to aim for. Defaults to 0.1 (10% FDR).

step_size

A numeric value giving the step size for sliding from the start to finish Desirability thresholds. Defaults to 0.1.

Value

A data frame of FDR estimates at each Desirability threshold.

Author(s)

Alex T. Kalinka alex.kalinka@cancer.org.uk


alex-kalinka-cruk/crispRutils documentation built on March 13, 2021, 7:52 p.m.